chiark / gitweb /
Handle flags on challenge timers correctly to prevent confusing the event
[tripe] / tripe.h
diff --git a/tripe.h b/tripe.h
index 41744837aea6e10ce9c92ce597c94c808274f4c4..1f73d6ba22ddcf5a33072189666351e8de68e7a9 100644 (file)
--- a/tripe.h
+++ b/tripe.h
@@ -1,6 +1,6 @@
 /* -*-c-*-
  *
- * $Id: tripe.h,v 1.13 2003/04/06 10:26:35 mdw Exp $
+ * $Id: tripe.h,v 1.15 2003/05/16 12:09:03 mdw Exp $
  *
  * Main header file for TrIPE
  *
 /*----- Revision history --------------------------------------------------* 
  *
  * $Log: tripe.h,v $
+ * Revision 1.15  2003/05/16 12:09:03  mdw
+ * Allow binding to a chosen address.
+ *
+ * Revision 1.14  2003/04/06 10:36:33  mdw
+ * Rearrange so as not to include Linux headers unless we need to.
+ *
  * Revision 1.13  2003/04/06 10:26:35  mdw
  * Report peer name on decrypt errors.
  *
 #include <arpa/inet.h>
 #include <netdb.h>
 
-#if TUN_TYPE == TUN_LINUX
-#  include <linux/if.h>
-#  include <linux/if_tun.h>
-#endif
-
 #include <pwd.h>
 #include <grp.h>
 
@@ -388,6 +389,11 @@ enum {
  * Used to maintain system-specific information about the tunnel interface.
  */
 
+#if TUN_TYPE == TUN_LINUX
+#  include <linux/if.h>
+#  include <linux/if_tun.h>
+#endif
+
 typedef struct tunnel {
 #if TUN_TYPE == TUN_UNET 
   sel_file f;                          /* Selector for Usernet device */
@@ -890,14 +896,15 @@ extern const addr *p_addr(peer */*p*/);
 
 /* --- @p_init@ --- *
  *
* Arguments:  @unsigned port@ = port number to listen to
  *
  * Returns:    ---
  *
  * Use:                Initializes the peer system; creates the socket.
  */
 
-extern void p_init(unsigned /*port*/);
+extern void p_init(struct in_addr /*addr*/, unsigned /*port*/);
 
 /* --- @p_port@ --- *
  *
@@ -890,14 +896,15 @@ extern const addr *p_addr(peer */*p*/);
 /* --- @p_init@ --- *
  *
- * Arguments:  @unsigned port@ = port number to listen to
+ * Arguments:  @struct in_addr addr@ = address to bind to
+ *             @unsigned port@ = port number to listen to
  *
  * Returns:    ---